package OME;

import OME.*;
import java.awt.*;
import java.awt.event.*;
import java.io.*;
import java.util.*;
import javax.swing.*;
import javax.swing.border.*;

/** Creates the main window, with the project manager.
 *  @author  Ying Shi
 *  @version Nov 1999
 */

class OME extends JFrame {
    
    static final int DEFAULT_WIDTH = 500;
    static final int DEFAULT_HEIGHT = 250; //cai

    // We should create a globals class.  Eventually we should be reading these
    // sorts of things from a config file.
    static final String projectdir = ".." + File.separator + "projects";
    private ProjectManager pm;


    /** Run the program. */
    public static void main(String[] args) {
	try {
	    UIManager.setLookAndFeel(UIManager.getSystemLookAndFeelClassName());
	} catch (Exception e) { 
	    D.o(e); 
	}
	new OME();
    }
    
    
    /** Constructs a new OME window */
    public OME() {		
	super("Organization Modelling Environment 3.0");

	// position and size window:	
	setSize(DEFAULT_WIDTH, DEFAULT_HEIGHT);	
	Dimension d = getToolkit().getScreenSize();
	Rectangle b = getBounds();
	setLocation((d.width - b.width)/2, (d.height - b.height)/2);    

	Container contentpane = getContentPane();
	contentpane.setLayout(new BorderLayout(0,0));	

	// create and add the project manager	
	pm = new ProjectManager(this);	
	contentpane.add(pm, BorderLayout.CENTER);
	// create and add the menubar
	contentpane.add(createMenuBar(), BorderLayout.NORTH);	
	
	addWindowListener(new MyWindowAdapter());
	setVisible(true);	
    }

          
    /** Creates the menu for the main frame window. */
    protected JMenuBar createMenuBar() {
	
	JMenuBar menubar = new JMenuBar();

	JMenuPlus filemenu = new JMenuPlus("File");
	filemenu.setMnemonic('f');		
	filemenu.add(new ExitAction());		
	menubar.add(filemenu);	
	
	// add the menus from project manager
	Iterator i = pm.getAvailableMenus().iterator();
	while (i.hasNext()) {
	    JMenuPlus menu = (JMenuPlus)i.next();
	    menubar.add(menu);
	}
	
	return menubar;
    }

    
    /** The action to exit the program. */
    class ExitAction extends AbstractAction {
	
	public ExitAction() {
	    super("Exit");
	}    
	
	public void actionPerformed (ActionEvent event) {
  	    System.exit(0);
	}
    }    
 
    
    /** The windows event adapter for this frame window. */
    class MyWindowAdapter extends WindowAdapter {
	public void windowClosing(WindowEvent e) { System.exit(0);}
    } 
    

}

